pub enum AsinBadge {
BRANDNOTELIGIBLE,
CATALOGNOTFOUND,
CONTENTNOTPUBLISHED,
CONTENTPUBLISHED,
}Expand description
AsinBadge : A flag that provides additional information about an ASIN. This is contextual and may change depending on the request that generated it. A flag that provides additional information about an ASIN. This is contextual and may change depending on the request that generated it.
Variants
BRANDNOTELIGIBLE
CATALOGNOTFOUND
CONTENTNOTPUBLISHED
CONTENTPUBLISHED